@@ -1,7 +1,11 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::Marshal::HTTP;
+BEGIN {
+  $JSON::RPC::Common::Marshal::HTTP::VERSION = '0.09';
+}
 use Moose;
+# ABSTRACT: Convert L<HTTP::Request> and L<HTTP::Response> to/from L<JSON::RPC::Common> calls and returns.
 
 use Carp qw(croak);
 
@@ -382,7 +386,9 @@ sub write_result_to_response {
 		}
 	}
 
-	croak "BAH" if keys %args;
+	if (my @keys = keys %args) {
+		croak "Unhandled response params: " . join ' ', @keys;
+	}
 
 	return 1;
 }
@@ -424,7 +430,7 @@ sub response_to_result_error {
 sub result_to_response {
 	my ( $self, $result ) = @_;
 
-	$self->create_http_response( $self->result_to_response_params($result) );
+	$self->create_http_response( $self->result_to_response_headers($result) );
 }
 
 sub create_http_response {
@@ -440,7 +446,7 @@ sub create_http_response {
 	);
 }
 
-sub result_to_response_params {
+sub result_to_response_headers {
 	my ( $self, $result ) = @_;
 
 	my $body = $self->encode($result->deflate);
@@ -453,18 +459,33 @@ sub result_to_response_params {
 	);
 }
 
+sub result_to_response_params {
+	my ( $self, $result ) = @_;
+
+	my %headers = $self->result_to_response_headers($result);
+	$headers{content_type} = delete $headers{Content_Type};
+	$headers{content_length} = delete $headers{Content_Length};
+
+	return %headers;
+}
+
 __PACKAGE__->meta->make_immutable();
 
 __PACKAGE__
 
-__END__
 
+
+
+__END__
 =pod
 
 =head1 NAME
 
-JSON::RPC::Common::Marshal::HTTP - Convert L<HTTP::Request> and
-L<HTTP::Response> to/from L<JSON::RPC::Common> calls and returns.
+JSON::RPC::Common::Marshal::HTTP - Convert L<HTTP::Request> and L<HTTP::Response> to/from L<JSON::RPC::Common> calls and returns.
+
+=head1 VERSION
+
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -619,6 +640,16 @@ Note that this is B<NOT> in any of the JSON-RPC specs.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
