@@ -1,7 +1,11 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::Message;
+BEGIN {
+  $JSON::RPC::Common::Message::VERSION = '0.09';
+}
 use Moose::Role;
+# ABSTRACT: JSON-RPC message role
 
 use Carp qw(croak);
 
@@ -66,4 +70,28 @@ sub _version_class {
 
 __PACKAGE__
 
+
 __END__
+=pod
+
+=head1 NAME
+
+JSON::RPC::Common::Message - JSON-RPC message role
+
+=head1 VERSION
+
+version 0.09
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
