@@ -1,7 +1,11 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::Procedure::Call;
+BEGIN {
+  $JSON::RPC::Common::Procedure::Call::VERSION = '0.09';
+}
 use Moose;
+# ABSTRACT: JSON RPC Procedure Call base class.
 
 use Try::Tiny;
 use JSON::RPC::Common::TypeConstraints qw(JSONValue);
@@ -158,14 +162,20 @@ __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
 
-__END__
 
+
+
+__END__
 =pod
 
 =head1 NAME
 
 JSON::RPC::Common::Procedure::Call - JSON RPC Procedure Call base class.
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use JSON::RPC::Common::Procedure::Call;
@@ -270,6 +280,16 @@ the return value.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
