@@ -1,7 +1,11 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::Procedure::Return;
+BEGIN {
+  $JSON::RPC::Common::Procedure::Return::VERSION = '0.09';
+}
 use Moose;
+# ABSTRACT: JSON-RPC procedure return class
 
 use Carp qw(croak);
 
@@ -98,14 +102,21 @@ __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
 
-__END__
 
+
+
+
+__END__
 =pod
 
 =head1 NAME
 
 JSON::RPC::Common::Procedure::Return - JSON-RPC procedure return class
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use JSON::RPC::Common::Procedure::Return;
@@ -189,7 +200,16 @@ L<JSON::RPC::Common::Procedure::Return::Error/new_dwim>.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
