@@ -1,7 +1,11 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::Procedure::Return::Error;
+BEGIN {
+  $JSON::RPC::Common::Procedure::Return::Error::VERSION = '0.09';
+}
 use Moose;
+# ABSTRACT: Base class for JSON-RPC errors
 
 use JSON::RPC::Common::TypeConstraints qw(JSONValue);
 
@@ -69,14 +73,20 @@ __PACKAGE__->meta->make_immutable();
 
 __PACKAGE__
 
-__END__
 
+
+
+__END__
 =pod
 
 =head1 NAME
 
 JSON::RPC::Common::Procedure::Return::Error - Base class for JSON-RPC errors
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use JSON::RPC::Common::Procedure::Return::Error;
@@ -134,6 +144,16 @@ what it accepts.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
