@@ -1,6 +1,10 @@
 #!/usr/bin/perl
 
 package JSON::RPC::Common::TypeConstraints;
+BEGIN {
+  $JSON::RPC::Common::TypeConstraints::VERSION = '0.09';
+}
+# ABSTRACT: Type constraint library
 
 use strict;
 use warnings;
@@ -16,14 +20,20 @@ subtype JSONContainer, as ArrayRef|HashRef;
 
 __PACKAGE__
 
-__END__
 
+
+
+__END__
 =pod
 
 =head1 NAME
 
 JSON::RPC::Common::TypeConstraints - Type constraint library
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use JSON::RPC::Common::TypeConstraints qw(JSONValue);
@@ -50,6 +60,16 @@ C<ArrayRef|HashRef>
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
